//@+leo
//@+node:0::@file src/main.c
//@+body
//@@language c
/*
    rox-tasklist    provides a tasklist for the rox desktop
    Copyright (C) 2002  Robert Lowe

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    The author may be contacted at pngwen@acm.org
*/

//@<< main #includes >>
//@+node:1::<< main #includes >>
//@+body
#include "xfun.h"
#include "task-gui.h"
#include "config-gui.h"
#include "about.h"
#include "globals.h"
#include <stdio.h>

//@-body
//@-node:1::<< main #includes >>


//@<< main declarations >>
//@+node:2::<< main declarations >>
//@+body

static gint button_press(GtkWidget*widget,
			 GdkEvent* event);

//@-body
//@-node:2::<< main declarations >>


//@+others
//@+node:3::destroy
//@+body
void destroy(GtkWidget* widget, gpointer data)
{
  gtk_main_quit();
}

//@-body
//@-node:3::destroy
//@+node:4::button_press
//@+body
static gint button_press(GtkWidget*widget,
			 GdkEvent* event)
{
  if(event->button.button==3)
  {
    gtk_menu_popup(GTK_MENU(GeneralMenu), NULL, NULL, NULL, NULL,
		  event->button.button, event->button.time);
    return TRUE;
  }
  return FALSE;
}

//@-body
//@-node:4::button_press
//@+node:5::main
//@+body
int main(int argc, char** argv)
{
  GList* task_list;
  GtkWidget* seap;
  GtkWidget* menu_item;
  GtkWidget* hscroller=0;
  char buf[100];
 
  viewbox=0;

  gtk_init(&argc, &argv);
  tasklist=0;

  /* detect if applet mode or application mode and respond accordingly */
  if(argc<2)
  {
    isapplet=FALSE;
    mainwin=gtk_window_new(GTK_WINDOW_TOPLEVEL);
  }
  else
  {
    isapplet=TRUE;
    mainwin=gtk_plug_new(atoi(argv[1]));
  }

  /* init the configuration */
  configure_init();

  /* set up mainwindow size stuff */
  gtk_widget_set_usize(mainwin, config_options.width, HEIGHT);
  gtk_window_set_policy(GTK_WINDOW(mainwin), FALSE, FALSE, TRUE);

  /* build general menu */
  GeneralMenu=gtk_menu_new();

  /* add the about option */
  sprintf(buf, "About");
  menu_item=gtk_menu_item_new_with_label(buf);
  gtk_menu_append(GTK_MENU(GeneralMenu), menu_item);
  gtk_signal_connect_object(GTK_OBJECT(menu_item), "activate",
			    GTK_SIGNAL_FUNC(about), NULL);
  gtk_widget_show(menu_item);

  /* add the configure option */
  sprintf(buf, "Configure");
  menu_item=gtk_menu_item_new_with_label(buf);
  gtk_menu_append(GTK_MENU(GeneralMenu), menu_item);
  gtk_signal_connect_object(GTK_OBJECT(menu_item), "activate",
			    GTK_SIGNAL_FUNC(configure), NULL);
  gtk_widget_show(menu_item);

  /* add the quit option */
  sprintf(buf, "Quit");
  menu_item=gtk_menu_item_new_with_label(buf);
  gtk_menu_append(GTK_MENU(GeneralMenu), menu_item);
  gtk_signal_connect_object(GTK_OBJECT(menu_item), "activate",
			    GTK_SIGNAL_FUNC(destroy), NULL);
  gtk_widget_show(menu_item);



  gtk_signal_connect(GTK_OBJECT(mainwin), "destroy", 
                     GTK_SIGNAL_FUNC(destroy), NULL);
  gtk_signal_connect(GTK_OBJECT(mainwin), "button_press_event",
		     GTK_SIGNAL_FUNC(button_press), NULL);



  /* make windows main hbox */
  winbox=gtk_hbox_new(0, 0);
  gtk_container_add(GTK_CONTAINER(mainwin), winbox);

  /* make the double separator handle */
  seap=gtk_vseparator_new();
  gtk_box_pack_start(GTK_BOX(winbox), seap,0,0,0);
  gtk_signal_connect(GTK_OBJECT(seap), "button_press_event",
		     GTK_SIGNAL_FUNC(button_press), NULL);
  seap=gtk_vseparator_new();
  gtk_box_pack_start(GTK_BOX(winbox), seap,0,0,0);
  gtk_signal_connect(GTK_OBJECT(seap), "button_press_event",
		     GTK_SIGNAL_FUNC(button_press), NULL);

  


  /* make the viewport, it's box and its adjustment */
  view=gtk_viewport_new(NULL, NULL);
  viewbox=gtk_vbox_new(0,0);
  if(config_options.mode==SCROLLED)
    hscroller=gtk_hscrollbar_new(gtk_viewport_get_hadjustment(GTK_VIEWPORT(view)));
  gtk_box_pack_start(GTK_BOX(viewbox), view, TRUE, TRUE,0);
  if(config_options.mode==SCROLLED)
  {
    gtk_box_pack_start(GTK_BOX(viewbox), hscroller, 0,0,0);
    gtk_signal_connect(GTK_OBJECT(hscroller), "button_press_event",
                       GTK_SIGNAL_FUNC(button_press), NULL);
  }
  viewscroll=hscroller;


  /* add the viewport's box to the winbox */
  gtk_box_pack_start(GTK_BOX(winbox), viewbox, TRUE, TRUE, 0);



  /* make the mainbox */
  mainbox=gtk_hbox_new(0, 0);
  gtk_container_add(GTK_CONTAINER(view), mainbox);

  taskMenu_init(); 
  task_list=xfun_init();

  gtk_widget_show_all(mainwin);
  gtk_main();
  return 0;
}

//@-body
//@-node:5::main
//@-others


//@-body
//@-node:0::@file src/main.c
//@-leo
